# MaterialClassificationCSVExportRequest

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**material_classification_classification** | [**MaterialClassificationClassification**](MaterialClassificationClassification.md) |  | 
**material_classification_reference_number** | **str** | Max length 50 characters | [optional] 
**street_descriptor** | **str** | Max length 100 characters | [optional] 
**usrn** | **str** | Max length 100 characters | [optional] 
**sample_date_from** | **datetime** |  | [optional] 
**sample_date_to** | **datetime** | Must occur on or after sample_date_from | [optional] 
**date_created_from** | **datetime** |  | [optional] 
**date_created_to** | **datetime** | Must occur on or after date_created_from | [optional] 
**export_description** | **str** | Max length 50 characters | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

